pub enum ServerState {
Uninitialized,
Initializing,
Initialized,
Operating,
ShuttingDown,
Shutdown,
}Expand description
MCP Server state
Variants
Implementations
Sourceimpl ServerState
impl ServerState
Sourcepub fn can_operate(&self) -> bool
pub fn can_operate(&self) -> bool
Check if the server can accept operations According to MCP 2025-06-18 specification, operations are allowed once the server is initialized (after initialize response)
Sourcepub fn is_initialized(&self) -> bool
pub fn is_initialized(&self) -> bool
Check if the server is initialized
Sourcepub fn is_shutting_down(&self) -> bool
pub fn is_shutting_down(&self) -> bool
Check if the server is shutting down